# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from apitax.api.models.base_model_ import Model
from apitax.api import util


class Script(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    def __init__(self, content=None, name=None):  # noqa: E501
        """Script - a model defined in Swagger

        :param content: The content of this Script.  # noqa: E501
        :type content: str
        :param name: The name of this Script.  # noqa: E501
        :type name: str
        """
        self.swagger_types = {
            'content': str,
            'name': str
        }

        self.attribute_map = {
            'content': 'content',
            'name': 'name'
        }

        self._content = content
        self._name = name

    @classmethod
    def from_dict(cls, dikt):
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The Script of this Script.  # noqa: E501
        :rtype: Script
        """
        return util.deserialize_model(dikt, cls)

    @property
    def content(self):
        """Gets the content of this Script.


        :return: The content of this Script.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this Script.


        :param content: The content of this Script.
        :type content: str
        """

        self._content = content

    @property
    def name(self):
        """Gets the name of this Script.


        :return: The name of this Script.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Script.


        :param name: The name of this Script.
        :type name: str
        """

        self._name = name
